@@ -1,5 +1,8 @@
 package Text::ANSITable::StyleSet::AltRow;
 
+our $DATE = '2014-12-12'; # DATE
+our $VERSION = '0.37'; # VERSION
+
 use 5.010;
 use Moo;
 use namespace::clean;
@@ -51,7 +54,7 @@ Text::ANSITable::StyleSet::AltRow
 
 =head1 VERSION
 
-This document describes version 0.36 of Text::ANSITable::StyleSet::AltRow (from Perl distribution Text-ANSITable), released on 2014-12-11.
+This document describes version 0.37 of Text::ANSITable::StyleSet::AltRow (from Perl distribution Text-ANSITable), released on 2014-12-12.
 
 =for Pod::Coverage ^(summary|apply)$
 
@@ -71,7 +74,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Text-ANSIT
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Text-ANSITable>.
+Source repository is at L<https://github.com/sharyanto/perl-Text-ANSITable>.
 
 =head1 BUGS
 
